import 'dart:convert';
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:platform_device_id/platform_device_id.dart';
import 'package:share_app_new/model/user_bean.dart';
import 'package:share_app_new/screens/app_registration_screen.dart';
import 'package:share_app_new/screens/invitation_form.dart';
import 'package:share_app_new/utils/common_utils.dart';
import 'package:share_app_new/utils/string_utils.dart';
import 'package:shared_preferences/shared_preferences.dart';

import '../utils/common_utils.dart';
import '../utils/list_utils.dart';
import '../utils/string_utils.dart';

class ShareAppsNew {
  static init(
      {String secreteKey, String appId, String email, String app_name}) {
    StringUtils.APP_ID = appId;
    StringUtils.APP_SECRET = secreteKey;
    StringUtils.APP_EMAIL = email;
    StringUtils.YOUR_APP_NAME = app_name;
  }

  static sendInvitation({BuildContext context}) async {
    if (StringUtils.APP_ID.isEmpty ||
        StringUtils.APP_SECRET.isEmpty ||
        StringUtils.APP_EMAIL.isEmpty ||
        StringUtils.YOUR_APP_NAME.isEmpty) {
      CommonUtils.showToast(
          "Please initialize app with appId, secreteKey Your registered email address and App Name",
          Colors.black);
      return;
    }

    final prefs = await SharedPreferences.getInstance();
    if (prefs.getString(StringUtils.USER_DATA) == null) {
      Navigator.push(
          context,
          MaterialPageRoute(
              builder: (context) =>
                  InvitationForm(new UserBean('', '', '', '', '', '', ''))));
    } else {
      Map jsons = json.decode(prefs.getString(StringUtils.USER_DATA));
      UserBean bean = UserBean(
          jsons['first_name'],
          jsons['last_name'],
          jsons['email'],
          jsons['phone'],
          jsons['country_id'],
          jsons['language'],
          jsons['deviceId']);
      showDialog<void>(
        context: context,
        barrierDismissible: false, // user must tap button!
        builder: (BuildContext context) {
          return AlertDialog(
            title: Text(
                'Do you want to edit credentials or continue with saved data?'),
            actions: <Widget>[
              FlatButton(
                child: Text('Edit'),
                onPressed: () {
                  Navigator.of(context).pop();
                  Navigator.push(
                      context,
                      MaterialPageRoute(
                          builder: (context) => InvitationForm(bean)));
                },
              ),
              FlatButton(
                child: Text('Continue'),
                onPressed: () async {
                  Navigator.of(context).pop();
                  try {
                    final result = await InternetAddress.lookup('google.com');
                    if (result.isNotEmpty && result[0].rawAddress.isNotEmpty) {
                      Route route = MaterialPageRoute(
                          builder: (context) =>
                              AppRegistrationScreen(bean, false));
                      Navigator.push(context, route);
                    }
                  } on SocketException catch (_) {
                    CommonUtils.showToast(
                        StringUtils.CHECK_NETWORK, Colors.red);
                  }
                  //openNextScreen(context, bean);
                },
              ),
            ],
          );
        },
      );
    }
  }

  static sendInvitationInBackground(
      {BuildContext context,
      String firstName,
      String lastName,
      String email,
      String countryCode,
      String language,
      String number}) async {
    Navigator.of(context).pop();
    try {
      final result = await InternetAddress.lookup('google.com');
      if (result.isNotEmpty && result[0].rawAddress.isNotEmpty) {
        CommonUtils.showToast("Please wait...", Colors.white);

        CommonUtils.GetCountryListData(context).then((value) async {
          if (StringUtils.APP_ID.isEmpty ||
              StringUtils.APP_SECRET.isEmpty ||
              StringUtils.APP_EMAIL.isEmpty ||
              StringUtils.YOUR_APP_NAME.isEmpty) {
            CommonUtils.showToast(
                "Please initialize app with appId, secreteKey Your registered email address and App Name",
                Colors.black);
            return;
          }
          if (firstName.length <= 0) {
            CommonUtils.showToast(StringUtils.ERROR_FIRST_NAME, Colors.red);
          } else if (lastName.length <= 0) {
            CommonUtils.showToast(StringUtils.ERROR_LAST_NAME, Colors.red);
          } else if (email.length <= 0) {
            CommonUtils.showToast(StringUtils.ERROR_EMAIL, Colors.red);
          } else if (!CommonUtils.validateEmail(email)) {
            CommonUtils.showToast(StringUtils.ERROR_VALID_EMAIL, Colors.red);
          } else if (number.length < 5) {
            CommonUtils.showToast(StringUtils.ERROR_NUMBER, Colors.red);
          } else if (ListUtil.countryList
              .where((element) => (element.cncode.compareTo(countryCode)) == 0)
              .isEmpty) {
            CommonUtils.showToast(StringUtils.ERROR_COUNTRY, Colors.red);
          } else if (language == '') {
            CommonUtils.showToast('Select Language', Colors.red);
          } else if (!ListUtil.language_list.contains(language)) {
            CommonUtils.showToast(StringUtils.ERROR_LANGUAGE, Colors.red);
          } else {
            if (!number.contains("+")) {
              number = ListUtil.countryList
                      .firstWhere((element) =>
                          element.cncode.toString().compareTo(countryCode) == 0)
                      .callCode
                      .toString() +
                  number;
            }
            UserBean bean = new UserBean(
                firstName,
                lastName,
                email,
                number,
                // ListUtil.country_sort_code_list.indexOf(countryCode).toString(),
                countryCode,
                language,
                await PlatformDeviceId.getDeviceId);
            final prefs = await SharedPreferences.getInstance();
            prefs.setString(StringUtils.USER_DATA, jsonEncode(bean.toJson()));
            try {
              final result = await InternetAddress.lookup('google.com');
              if (result.isNotEmpty && result[0].rawAddress.isNotEmpty) {
                Route route = MaterialPageRoute(
                    builder: (context) => AppRegistrationScreen(bean, true));
                Navigator.push(context, route);
              }
            } on SocketException catch (_) {
              CommonUtils.showToast(StringUtils.CHECK_NETWORK, Colors.red);
            }
          }
        });
      }
    } on SocketException catch (_) {
      CommonUtils.showToast(StringUtils.CHECK_NETWORK, Colors.red);
    }
  }
}
