import 'dart:convert';
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:http/http.dart' as http;
import 'package:platform_device_id/platform_device_id.dart';
import 'package:share_app_new/model/country_bean.dart';
import 'package:share_app_new/utils/string_utils.dart';
import 'package:url_launcher/url_launcher.dart';

import 'list_utils.dart';

class CommonUtils {
  static Future<bool> checkInternetConnection() async {
    try {
      final result = await InternetAddress.lookup('google.com');
      if (result.isNotEmpty && result[0].rawAddress.isNotEmpty) {
        return true;
      }
    } on SocketException catch (_) {
      showToast(StringUtils.CHECK_NETWORK, Colors.red);
      return false;
    }
  }

  static void showToast(String msg, Color color) {
    Fluttertoast.showToast(
        msg: msg,
        toastLength: Toast.LENGTH_SHORT,
        gravity: ToastGravity.BOTTOM,
        timeInSecForIosWeb: 1,
        backgroundColor: Colors.black,
        textColor: Colors.white,
        fontSize: 16.0);
  }

  static Future<dynamic> apiCall(
      Uri url, String body, BuildContext context) async {
    return http
        .post(url, body: body, headers: StringUtils.GetApiHeaders())
        .then((http.Response response) {
      Map<String, dynamic> map = json.decode(response.body);
      final int statusCode = response.statusCode;
      if (statusCode < 200 || statusCode > 400 || json == null) {
        // CommonUtils.showToast(map[StringUtils.MESSAGE], Colors.red);
        Navigator.pop(context);
        throw new Exception("Error while fetching data");
      }
      return map;
    });
  }

  static Future<dynamic> apiCallGet(Uri url, BuildContext context) async {
    return http.get(url).then((http.Response response) {
      List<dynamic> map = jsonDecode(response.body.toString());
      if (map != null && map.length > 0) {
        ListUtil.countryList =
            List<CountryBean>.from(map.map((i) => CountryBean.fromJson(i)));
      }
      return map;
    });
  }

  static bool validateEmail(String value) {
    Pattern pattern =
        r'^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$';
    RegExp regex = new RegExp(pattern);
    return (!regex.hasMatch(value)) ? false : true;
  }

  static openURL(String url) async {
    if (await canLaunch(url)) {
      await launch(url);
    } else {
      throw 'Could not launch $url';
    }
  }

  static String getPlatform() {
    String platform;
    if (Platform.isAndroid) {
      platform = "3";
    } else if (Platform.isIOS) {
      platform = "2";
    }
    return platform;
  }

  Future<String> initPlatformState() async {
    // Platform messages may fail, so we use a try/catch PlatformException.
    try {
      StringUtils.deviceId = await PlatformDeviceId.getDeviceId;
    } on PlatformException {
      StringUtils.deviceId = 'Unknown';
    }

    return StringUtils.deviceId;
    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
  }

  static Future<void> GetCountryListData(BuildContext context) async {
    List<dynamic> map = await CommonUtils.apiCallGet(
        Uri.parse(StringUtils.GET_COUNTRY_LIST), context);
  }
}
